# HADDOCK3 DISCLAIMER

The HADDOCK3 software is provided "as is" and without warranties.
The authors of the software will not be held liable for any use of the HADDOCK3 package and derivatives/results. 

Some of HADDOCK3 modules use the CNS software (<http://cns-online.org/v1.3/>) (Crystallography and NMR System) 
as computational engine.

While CNS is free of use for non-profit users, a proper license is required for commercial applications. 
Biovia is handling those licenses (<https://www.3ds.com/how-to-buy/contact-sales>). 
While they officially do not distribute CNS (CNX) anymore, they usually allow the use of the non-profit version 
provided a proper license is purchased for some of their modelling software.

The HADDOCK3 modules using CNS are:

- topology modules:
  - topoaa
  - topocg

- sampling modules:
  - rigidbody

- refinement modules:
  - flexref
  - emref
  - mdref

- scoring modules:
  - emscoring
  - mdscoring
	
- analysis modules:
  - alascan

Commercial use of any of the above-mentioned modules in a HADDOCK3 workflow will thus require a proper CNS license.
It is your responsibility as a user to make sure you have such a license.

